package ALTLinux::RepoList::CLI;

use strict;
use warnings;
use Carp;
use Source::Shared::FindLocalMirror::ALTLinux;
use ALTLinux::RepoList qw(load_listfile_lambda_fn listdirs2srclists listdirs2binlists);
use Source::Shared::CLI;
our @ISA = qw/Source::Shared::CLI/;

our $VERSION=0.001;
#our $verbose=0;
#$verbose=1 if $ENV{TERM}; # not to pollute cron mail

our @binlists;
our @srclists;
my @REPO;
my @listdir;

my $infile;

our @LONGOPT=(
    'listdir=s' => \@listdir,
    'repo=s' => \@REPO,
    'bin-list=s' => \@binlists,
    'src-list=s' => \@srclists,
    'infile=s' => \$infile,
    );
sub print_longopt {
    print "  ALTLinux::RepoList options:
	--listdir <dir> /path/to/files/list/ dir
	--repo <dir> /path/to/repo dir (should have files/list subdir)
	--bin-list /path/to/bin.list
	--src-list /path/to/src.list
	--infile input file (optional)
";
}

sub cli_container_ref {
    return ['Source::Shared::FindLocalMirror::ALTLinux'];
}

our $need_bin=0;
our $need_src=0;
our @IN;

sub process_options {
    if ($need_bin and @binlists==0 or $need_src and @srclists==0) {
	push @listdir, map {-d $_.'/files/list' ? $_.'/files/list': $_} @REPO if @REPO;
	push @listdir, &Source::Shared::FindLocalMirror::ALTLinux::find_cli(-subpath=>'files/list') unless @listdir;
	push @srclists, &listdirs2srclists(@listdir);
	push @binlists, &listdirs2binlists(@listdir);
    }

    if ($need_bin and @binlists==0 or $need_src and @srclists==0) {
	warn "Can't find bin.list. Use --bin-list=/path\n" if $need_bin and @binlists==0;
	warn "Can't find src.list. Use --src-list=/path\n" if $need_src and @srclists==0;
	die "or use --listdir <dir> /path/to/files/list/ dir\n";
    }

    # should be process_arguments
    # ------- @IN --------------
    &load_listfile_lambda_fn($infile,
    sub {
	my ($fn)=@_;
	while (my $line=<$fn>) {
	    chomp $line;
	    $line=~s/^\s*//;
	    $line=~s/\s*$//;
	    push @IN, $line;
	}
	}) if $infile;
    push @IN, @ARGV;
    # ------- END @IN -----------
}

1;
